@@ -175,7 +175,7 @@ class DataSetsManager(ManagerMix):
 
         a = self._client._session.post(data_set.url+"/data", data=out)
         if a.status_code != 200:
-            raise Exception("upload fail on server side")
+            raise Exception("upload fail on server side "+a.text)
 
 
 
